@@ -25,6 +25,7 @@
 #include "qzsettings.h"
 #include "tabwidget.h"
 #include "iconprovider.h"
+#include "statusbar.h"
 
 BookmarksMenu::BookmarksMenu(QWidget* parent)
     : Menu(parent)
@@ -93,6 +94,11 @@ void BookmarksMenu::menuAboutToShow()
     }
 }
 
+void BookmarksMenu::menuAboutToHide()
+{
+    mApp->getWindow()->statusBar()->clearMessage();
+}
+
 void BookmarksMenu::menuMiddleClicked(Menu* menu)
 {
     BookmarkItem* item = static_cast<BookmarkItem*>(menu->menuAction()->data().value<void*>());
@@ -173,6 +179,7 @@ void BookmarksMenu::init()
     connect(this, SIGNAL(aboutToShow()), this, SLOT(aboutToShow()));
     connect(this, SIGNAL(aboutToShow()), this, SLOT(menuAboutToShow()));
     connect(this, SIGNAL(menuMiddleClicked(Menu*)), this, SLOT(menuMiddleClicked(Menu*)));
+    connect(this, &QMenu::aboutToHide, this, &BookmarksMenu::menuAboutToHide);
 }
 
 void BookmarksMenu::refresh()
